# Code for the article:
# Metulini, R., R. Patuelli and D.A. Griffith (2018). A Spatial-Filtering Zero-Inflated Approach to the Estimation of the Gravity Model of Trade. Econometrics 6 (9): 11

# Function be.zeroinfl.filt.full.adjl
# To obtain robust s.e. we need to run coeftest() at the end, on the final output

be.zeroinfl.filt.full.adj1 = function (object, data, dist = c("poisson", "negbin", "geometric"), 
    alpha = 0.05, trace = FALSE, subset.zero, subset.count, minmod.zero, minmod.count, robust=FALSE)

# alpha defines the margin of error
# trace = TRUE to monitor intermediate results when the code is running
# subset.zero, subset.count, minmod.zero, minmod.count: list of the logit (zero) and count variables to keep into the model (minmod) and those subjected to stepwise (subset)
# robust = TRUE to run the stepwise using intermediate robust s.e. to compute p-values

{
if (robust==FALSE)

# this part is esecuted when robust = FALSE, otherwise the function esecutes the code for robust = TRUE
# this can not be considered a PPML estimation

{

    if (class(object) != "zeroinfl")
        stop("object must be zeroinfl\n")

# the object must be of class "zeroinfl"

	if(identical(attr(object$terms$count,"term.labels"), c(minmod.count, subset.count)) == FALSE)
	stop("the count variables in object must be equal, in this order, to the variables in minmod.count plus the variables in subset.count")
	if(identical(attr(object$terms$zero,"term.labels"), c(minmod.zero, subset.zero)) == FALSE)
	stop("the zero variables in object must be equal, in this order, to the variables in minmod.zero plus the variables in subset.zero, in this order")

# the list of variables in the logit (or count) part of the model included in "object" must be the same (same name and order) as the ones in the joined list of minmod.zero (or minmod.count) and subset.zero (or subset.count)

    dist <- match.arg(dist)
    fit <- object

# estimate zeroinfl defining in "dist" the choosen distribution

  nj <- length(subset.zero) * length(subset.count)  # total number of variables subjected to stepwise (to subset)
    j <- 1 # number of step (the first is step 1)
    if (trace) {
        cat("Initial model\n")
        print(summary(fit))
    }
    RET <- matrix(NA, nrow = nj, ncol = 3)
    colnames(RET) <- c("loglik", "BIC", "AIC")

# if trace = TRUE, print the model and return loglikelihood, AIC and BIC.


    while (T) {
        if (trace) 
            cat("\nstep", j, "\n")

# print the step number (the initial model is step 1), if trace = TRUE;

# Next lines of code: choose the smallest p-value for the variables in subset.count (count.max) and the smallest p-value for the variables in subset.zero (zero.max)

        coef <- summary(fit)$coef # define the list model coefficients
        d <- dim(coef$count)[1]  # define the total number of coefficients
            count.pval <- coef$count[names(fit$coeff$count) %in% subset.count, 4] # define the list of pvalues of the variables to be subsetted in the count part
                zero.pval <- coef$zero[names(fit$coeff$zero) %in% subset.zero, 4] # define the list of pvalues of the variables to be subsetted in the logit part
        nc <- length(count.pval) # dimension of the pvalues list for the count part
        nz <- length(zero.pval) # dimension of the pvalues list for the logit part
            count.order <- order(coef$count[names(fit$coeff$count) %in% subset.count, 4], decreasing = TRUE) # same of count.pval, but ordered from the largest
        zero.order <- order(coef$zero[names(fit$coeff$zero) %in% subset.zero, 4], decreasing = TRUE) # same of zero.pval, but ordered from the largest
    list.zero <- as.vector(subset.zero[subset.zero %in% attr(fit$terms$zero, "term.labels")]) # names (term.labels) of the variables to be subsetted in logit part
list.count <- as.vector(subset.count[subset.count %in% attr(fit$terms$count, "term.labels")]) # names (term.labels) of the variables to be subsetted in count part
        kc <- 1 # 1 because i want to select the largest pval in count part
        kz <- 1 # same for logit part
count.max <- count.pval[count.order[kc]] # it gives the value of the largest pval in count part
zero.max <- zero.pval[zero.order[kz]] # it gives the value of the largest pval in zero part
###

# next lines: if count.max is larger than zero.max and larger than alpha the variable related to count.max is dropped from the model;
###
        if (is.na(count.max) && is.na(zero.max)) 
            break
        else if (is.na(zero.max)) 
            zero.max <- 0
        else if (is.na(count.max)) 
            count.max <- 0
        if (count.max > zero.max) 
            if (count.max > alpha) {
                newid <- count.order[kc] 

                  dropvar <- rownames(coef$count)[names(fit$coeff$count) %in% subset.count][newid] # The dropped variables name is removed from subset.count

     if (trace) 

# if trace = TRUE, Drop variable in count component: variable name is printed

                  cat("drop variable in count component: ", subset.count[newid], 
                    "\n")
                list.count <- list.count[-newid] # A new object value is generated by replacing the new subset.count
 
                kc <- kc + 1 # kc is updated
            }



            else break
        else if (zero.max > alpha) {
    
# Next lines: else, if zero.max is larger than alpha the variable related to zero.max is dropped from the model

        newid <- zero.order[kc]
            dropvar <- rownames(coef$zero)[names(fit$coeff$zero) %in% subset.zero][newid]

            if (trace) 
                cat("drop variable in zero component: ", subset.zero[newid], 
                  "\n")

# if trace = TRUE, Drop variable in zero component: variable name is printed

            list.zero <- list.zero[-newid] # A new object value is generated by replacing the new subset.count
        }
        else break

# next lines: update model list of variables for the count part

       if (length(list.count) == 0)
             list.counttmp <- paste(minmod.count, collapse = ' + ') 
       else if (length(list.count) >= 1) {
list1.count = paste(minmod.count, collapse = ' + ')
list2.count = paste(list.count, collapse = ' + ')
list.counttmp <- paste(list1.count,"+",list2.count)
} 

# next lines: update model list of variables for the logit part

  if (length(list.zero) == 0)
             list.zerotmp <- paste(minmod.zero, collapse = ' + ')
       else if (length(list.zero) >= 1) {
list1.zero = paste(minmod.zero, collapse = ' + ')
list2.zero = paste(list.zero, collapse = ' + ')
list.zerotmp <- paste(list1.zero,"+",list2.zero)
} 

# Next lines:  Refit the zeroinfl model using the updated object value;

      res <- deparse(terms(fit$terms$count)[[2]])
     out <- paste(res, "~", list.counttmp, "|", list.zerotmp) 
       environment(out) <- parent.frame()
        fit <- try(zeroinfl(eval(parse(text = out)), data = data, 
            dist = dist))
        if (inherits(fit, "try-error")) 
            break

# Next lines: if trace = TRUE, print summary statistics, AIC, BIC and loglikelihood of the updated model

        if (trace) {
            print(summary(fit))
            cat("\nloglik of zero-inflated model", logLik(fit), 
                "\n")
            cat("\nBIC of zero-inflated model", AIC(fit, k = log(dim(data)[1])))
            cat("\nAIC of zero-inflated model", AIC(fit))
        }
        RET[j, 1] <- logLik(fit)
        RET[j, 2] <- AIC(fit, k = log(dim(data)[1]))
        RET[j, 3] <- AIC(fit)
        j <- j + 1
    }

# when no more p-values larger than the choosen level, if trace = TRUE, print final model results

    if (trace) 
        print(RET[complete.cases(RET), ])
    return(fit)
}

# end of code with traditional s.e.. This part is not executed if we set robust = TRUE

# same code, with robust s.e.. Roughly the same, but using robust s.e. for removing variables
# this CAN be considered a PPML estimation, as the vcov matrix takes into consideration the PPML adjustment

else if (robust == TRUE)

    if (class(object) != "zeroinfl") 
        stop("object must be zeroinfl\n")
	if(identical(attr(object$terms$count,"term.labels"), c(minmod.count, subset.count)) == FALSE)
	stop("the count variables in object must be equal, in this order, to the variables in minmod.count plus the variables in subset.count")
	if(identical(attr(object$terms$zero,"term.labels"), c(minmod.zero, subset.zero)) == FALSE)
	stop("the zero variables in object must be equal, in this order, to the variables in minmod.zero plus the variables in subset.zero")

    dist <- match.arg(dist)
   vcov = coeftest(object, vcov = sandwich1) # also computes vcov, as in the PPML, using the external "sandwich1" function (Look down in this file)
    fit <- object
  nj <- length(subset.zero) * length(subset.count) 
    j <- 1
    if (trace) {
        cat("Initial model\n")
        print(coeftest(fit, vcov = sandwich1)) # print robust s.e. results
    }
    RET <- matrix(NA, nrow = nj, ncol = 3)
    colnames(RET) <- c("loglik", "BIC", "AIC")

    while (T) {
        if (trace) 
            cat("\nstep", j, "\n")
        coef <- summary(fit)$coef
        vcov <- coeftest(fit, vcov = sandwich1)[,4] # define the complete list of p-values
        vcov.count <- vcov[substr(attr(vcov,"names"),1,6)=="count_"] # define the list of  ROBUST p-values of the variables to be subsetted in the logit part
        vcov.zero <- vcov[substr(attr(vcov,"names"),1,5)=="zero_"] # define the list of ROBUST  p-values of the variables to be subsetted in the zero part
        d <- dim(coef$count)[1] 
            count.pval <- vcov.count[substr(attr(vcov.count,"names"),7,nchar(attr(vcov.count,"names"))) %in% subset.count]
                zero.pval <- vcov.zero[substr(attr(vcov.zero,"names"),6,nchar(attr(vcov.zero,"names"))) %in% subset.zero]

            count.order <- order(as.numeric(strsplit(as.character(count.pval), " ")), decreasing = TRUE)
        zero.order <- order(as.numeric(strsplit(as.character(zero.pval), " ")), decreasing = TRUE)

    list.zero <- as.vector(subset.zero[subset.zero %in% attr(fit$terms$zero, "term.labels")])
list.count <- as.vector(subset.count[subset.count %in% attr(fit$terms$count, "term.labels")])
        kc <- 1
        kz <- 1
count.max <- count.pval[count.order[kc]]
zero.max <- zero.pval[zero.order[kz]]
        if (is.na(count.max) && is.na(zero.max)) 
            break
        else if (is.na(zero.max)) 
            zero.max <- 0
        else if (is.na(count.max)) 
            count.max <- 0
        if (count.max > zero.max) 
            if (count.max > alpha) {
                newid <- count.order[kc] 
                  dropvar <- rownames(coef$count)[names(fit$coeff$count) %in% subset.count][newid]
                if (trace) 
                  cat("drop variable in count component: ", dropvar, 
                    "\n")
                list.count <- list.count[-newid]
                kc <- kc + 1
            }
            else break
        else if (zero.max > alpha) {
            newid <- zero.order[kc]
            dropvar <- rownames(coef$zero)[names(fit$coeff$zero) %in% subset.zero][newid]
            if (trace) 
                cat("drop variable in zero component: ", dropvar, 
                  "\n")
            list.zero <- list.zero[-newid]
        }
        else break

       if (length(list.count) == 0)
             list.counttmp <- paste(minmod.count, collapse = ' + ') 
       else if (length(list.count) >= 1) {
list1.count = paste(minmod.count, collapse = ' + ')
list2.count = paste(list.count, collapse = ' + ')
list.counttmp <- paste(list1.count,"+",list2.count)
}

  if (length(list.zero) == 0)
             list.zerotmp <- paste(minmod.zero, collapse = ' + ') 
       else if (length(list.zero) >= 1) {
list1.zero = paste(minmod.zero, collapse = ' + ')
list2.zero = paste(list.zero, collapse = ' + ')
list.zerotmp <- paste(list1.zero,"+",list2.zero)
} 

        res <- deparse(terms(fit$terms$count)[[2]])
     out <- paste(res, "~", list.counttmp, "|", list.zerotmp)
       environment(out) <- parent.frame()
        fit <- try(zeroinfl(eval(parse(text = out)), data = data, 
            dist = dist))

        if (inherits(fit, "try-error")) 
            break
        if (trace) {
            print(coeftest(fit, vcov = sandwich1)) # print ROBUST results
            cat("\nloglik of zero-inflated model", logLik(fit), 
                "\n")
            cat("\nBIC of zero-inflated model", AIC(fit, k = log(dim(data)[1])))
            cat("\nAIC of zero-inflated model", AIC(fit))
        }
        RET[j, 1] <- logLik(fit)
        RET[j, 2] <- AIC(fit, k = log(dim(data)[1]))
        RET[j, 3] <- AIC(fit)
        j <- j + 1
    }
    if (trace) 
        print(RET[complete.cases(RET), ])
    return(fit)
}
# end function

# Function sandwich1, to take a zeroinfl object and compute its sandwitch robust s.e. corrected for n / (n-1), in order to get a PPML

sandwich1 = function(object){sandwich(object) * (object$n) / (object$n - 1)}

# end of function



# set dir
setwd("C:\\Users\\win7\\Dropbox\\2step negbin spat filt\\data")

#install libraries
library(sandwich)
library(pscl)
library(lmtest)

# table 1
data = read.delim("data.txt")
colnames(data)[7] <- "Tr_mil"
colnames(data)[8] <- "logdist"
colnames(data)[10] <- "comlang"
colnames(data)[12] <- "hist"
colnames(data)[28] <- "logarea"
colnames(data)[29] <- "loggdpcap"
colnames(data)[166] <- "logpop"
colnames(data)[30] <- "island"
colnames(data)[31] <- "landl"
summary(data[,c(7,8,10,9,12,13,28,29,166,30,31)])

# table 2

# column (1)

data = read.delim("data.txt")
# estimate the initial zeroinflated poisson model
init_model = zeroinfl(trademln ~ lndistcap + comlang_off + contig + history + fta + logarea_i + logarea_e + lngdpcap_i + lngdpcap_e + lnpop_i + lnpop_e + island_i + island_e + landlocked_i + landlocked_e +
	e1_o + e3_o + e4_o + e5_o + e7_o + e8_o + e9_o + e10_o + e11_o + e12_o + e13_o + e14_o + e15_o + e17_o + e18_o + e19_o + e20_o + e21_o + e22_o + e23_o + e24_o +
	e1_d + e2_d + e4_d + e5_d + e7_d + e8_d + e9_d + e10_d + e12_d + e13_d + e14_d + e16_d + e17_d + e18_d + e19_d + e20_d + e22_d + e23_d + e24_d + e25_d + e26_d + e27_d + e28_d + e29_d + e30_d +
	e1_od + e2_od + e3_od + e4_od + e5_od + e6_od + e7_od + e8_od + 
      e9_od + e10_od + e11_od + e12_od + e13_od + e14_od + e15_od + e16_od + e17_od + e18_od + e19_od + e20_od + e21_od + e22_od + e23_od + e24_od + 
      e25_od + e26_od + e27_od + e28_od + e29_od + e30_od + e31_od + e32_od + e33_od + e34_od + e35_od + e36_od + e37_od + e38_od + e39_od + e40_od + 
      e41_od + e42_od + e43_od + e44_od + e45_od + e46_od + e47_od + e48_od + e49_od + e50_od + e51_od + e52_od + e53_od + e54_od + e55_od + e56_od + 
      e57_od + e58_od + e59_od + e60_od | lndistcap + comlang_off + contig + history + fta + logarea_i + logarea_e + lngdpcap_i + lngdpcap_e + lnpop_i + lnpop_e + island_i + island_e + landlocked_i + landlocked_e +
	e1_o + e3_o + e4_o + e5_o + e7_o + e8_o + e9_o + e10_o + e11_o + e12_o + e13_o + e14_o + e15_o + e17_o + e18_o + e19_o + e20_o + e21_o + e22_o + e23_o + e24_o +
	e1_d + e2_d + e4_d + e5_d + e7_d + e8_d + e9_d + e10_d + e12_d + e13_d + e14_d + e16_d + e17_d + e18_d + e19_d + e20_d + e22_d + e23_d + e24_d + e25_d + e26_d + e27_d + e28_d + e29_d + e30_d + e1_od + e2_od + e3_od + e4_od + e5_od + e6_od + e7_od + e8_od + 
      e9_od + e10_od + e11_od + e12_od + e13_od + e14_od + e15_od + e16_od + e17_od + e18_od + e19_od + e20_od + e21_od + e22_od + e23_od + e24_od + 
      e25_od + e26_od + e27_od + e28_od + e29_od + e30_od + e31_od + e32_od + e33_od + e34_od + e35_od + e36_od + e37_od + e38_od + e39_od + e40_od + 
      e41_od + e42_od + e43_od + e44_od + e45_od + e46_od + e47_od + e48_od + e49_od + e50_od + e51_od + e52_od + e53_od + e54_od + e55_od + e56_od + 
      e57_od + e58_od + e59_od + e60_od , data = data, maxit = 10000,
dist = "poisson")
# define list inputs for the stepwise
subset.zero = names(init_model$coeff$count)[substr(names(init_model$coeff$count),1,1) == "e"]
subset.count = names(init_model$coeff$count)[substr(names(init_model$coeff$count),1,1) == "e"]
minmod.zero = names(init_model$coeff$count)[substr(names(init_model$coeff$count),1,1) != "e"][2:16]
minmod.count = names(init_model$coeff$count)[substr(names(init_model$coeff$count),1,1) != "e"][2:16]
# run the stepwise
final_model = be.zeroinfl.filt.full.adj1(init_model, data = data, dist = "poisson", alpha = 0.05, trace = TRUE, subset.zero =subset.zero,subset.count=subset.count, minmod.count=minmod.count, minmod.zero = minmod.zero, robust=TRUE)
# results
fit = coeftest(final_model, vcov = sandwich1)
#akaike index criteria
AIC(final_model)
# loglikelihood
logLik(final_model)
# mcfadden R^2
base = zeroinfl(trademln ~ 1 |1 , maxit = 10000, dist = "poisson", data= data)
InterceptModel_ZIPESF <- update(base, . ~ 1) 
L_Int = logLik(base)
L_Ful = logLik(final_model)
P_R2_MFad_ZIPESF = 1- L_Ful/L_Int
P_R2_MFad_ZIPESF

# column (2)

init.model = zeroinfl(trademln ~ lndistcap + comlang_off + contig + history + fta + logarea_i + logarea_e + lngdpcap_i + lngdpcap_e + lnpop_i + lnpop_e + island_i + island_e + landlocked_i + landlocked_e +
	e1_o + e3_o + e4_o + e5_o + e7_o + e8_o + e9_o + e10_o + e11_o + e12_o + e13_o + e14_o + e15_o + e17_o + e18_o + e19_o + e20_o + e21_o + e22_o + e23_o + e24_o +
	e1_d + e2_d + e4_d + e5_d + e7_d + e8_d + e9_d + e10_d + e12_d + e13_d + e14_d + e16_d + e17_d + e18_d + e19_d + e20_d + e22_d + e23_d + e24_d + e25_d + e26_d + e27_d + e28_d + e29_d + e30_d +
	e1_od + e2_od + e3_od + e4_od + e5_od + e6_od + e7_od + e8_od + 
      e9_od + e10_od + e11_od + e12_od + e13_od + e14_od + e15_od + e16_od + e17_od + e18_od + e19_od + e20_od + e21_od + e22_od + e23_od + e24_od + 
      e25_od + e26_od + e27_od + e28_od + e29_od + e30_od + e31_od + e32_od + e33_od + e34_od + e35_od + e36_od + e37_od + e38_od + e39_od + e40_od + 
      e41_od + e42_od + e43_od + e44_od + e45_od + e46_od + e47_od + e48_od + e49_od + e50_od + e51_od + e52_od + e53_od + e54_od + e55_od + e56_od + 
      e57_od + e58_od + e59_od + e60_od | lndistcap + comlang_off + contig + history + fta + logarea_i + logarea_e + lngdpcap_i + lngdpcap_e + lnpop_i + lnpop_e + island_i + island_e + landlocked_i + landlocked_e + e13_o, data = data, maxit = 10000,
dist = "poisson")
##DEFINE INPUTS FOR THE NEW CODES
subset.zero = names(init.model$coeff$zero)[substr(names(init.model$coeff$zero),1,1) == "e"]
subset.count = names(init.model$coeff$count)[substr(names(init.model$coeff$count),1,1) == "e"]
minmod.zero = names(init.model$coeff$count)[substr(names(init.model$coeff$count),1,1) != "e"][2:16]
minmod.count = names(init.model$coeff$count)[substr(names(init.model$coeff$count),1,1) != "e"][2:16]
final_model2 = be.zeroinfl.filt.full.adj1(init.model, data = data, dist = "poisson", alpha = 0.05, trace = TRUE, subset.zero =subset.zero,subset.count=subset.count, minmod.count=minmod.count, minmod.zero = minmod.zero, robust=TRUE)
# results
fit = coeftest(final_model2, vcov = sandwich1)
#akaike index criteria
AIC(final_model2)
# loglikelihood
logLik(final_model2)
# mcfadden R^2
base = zeroinfl(trademln ~ 1 |1 , maxit = 10000, dist = "poisson", data= data)
InterceptModel_ZIPESF <- update(base, . ~ 1) 
L_Int = logLik(base)
L_Ful = logLik(final_model2)
P_R2_MFad_ZIPESF = 1- L_Ful/L_Int
P_R2_MFad_ZIPESF

# column (3)

init.model = zeroinfl(trademln ~ lndistcap + comlang_off + contig + history + fta + logarea_i + logarea_e + lngdpcap_i + lngdpcap_e + lnpop_i + lnpop_e + island_i + island_e + landlocked_i + landlocked_e +
	e1_o + e3_o + e4_o + e5_o + e7_o + e8_o + e9_o + e10_o + e11_o + e12_o + e13_o + e14_o + e15_o + e17_o + e18_o + e19_o + e20_o + e21_o + e22_o + e23_o + e24_o +
	e1_d + e2_d + e4_d + e5_d + e7_d + e8_d + e9_d + e10_d + e12_d + e13_d + e14_d + e16_d + e17_d + e18_d + e19_d + e20_d + e22_d + e23_d + e24_d + e25_d + e26_d + e27_d + e28_d + e29_d + e30_d +
	e1_od + e2_od + e3_od + e4_od + e5_od + e6_od + e7_od + e8_od + 
      e9_od + e10_od + e11_od + e12_od + e13_od + e14_od + e15_od + e16_od + e17_od + e18_od + e19_od + e20_od + e21_od + e22_od + e23_od + e24_od + 
      e25_od + e26_od + e27_od + e28_od + e29_od + e30_od + e31_od + e32_od + e33_od + e34_od + e35_od + e36_od + e37_od + e38_od + e39_od + e40_od + 
      e41_od + e42_od + e43_od + e44_od + e45_od + e46_od + e47_od + e48_od + e49_od + e50_od + e51_od + e52_od + e53_od + e54_od + e55_od + e56_od + 
      e57_od + e58_od + e59_od + e60_od | e22_o + e24_o , data = data, maxit = 10000,
dist = "poisson")
##DEFINE INPUTS FOR THE NEW CODES
subset.zero = names(init.model$coeff$zero)[substr(names(init.model$coeff$zero),1,1) == "e"][2]
subset.count = names(init.model$coeff$count)[substr(names(init.model$coeff$count),1,1) == "e"]
minmod.zero = names(init.model$coeff$zero)[substr(names(init.model$coeff$zero),1,1) == "e"][1]
minmod.count = names(init.model$coeff$count)[substr(names(init.model$coeff$count),1,1) != "e"][2:16]
int_model3 = be.zeroinfl.filt.full.adj1(init.model, data = data, dist = "poisson", alpha = 0.05, trace = TRUE, subset.zero =subset.zero,subset.count=subset.count, minmod.count=minmod.count, minmod.zero = minmod.zero, robust=TRUE)
final_model3 = zeroinfl(trademln ~ lndistcap + comlang_off + contig + history + fta + logarea_i + logarea_e + lngdpcap_i + lngdpcap_e + lnpop_i + lnpop_e + island_i + island_e + landlocked_i + landlocked_e + e1_o + e4_o + e5_o + e7_o + e10_o + e19_o + e1_d + e7_d + e8_d + e14_d + e20_d + e23_d + e25_d + e3_od + e6_od + e8_od + e13_od + e14_od + e16_od + e19_od + e20_od + e24_od + e26_od + e31_od + e32_od + e35_od + e37_od + e39_od + e41_od + e44_od + e45_od + e47_od + e49_od + e50_od + e53_od + e58_od + e59_od | 1 , data = data, maxit = 10000, dist = "poisson")
#results
fit = coeftest(final_model3, vcov = sandwich1)
#akaike index criteria
AIC(final_model3)
# loglikelihood
logLik(final_model3)
# mcfadden R^2
base = zeroinfl(trademln ~ 1 |1 , maxit = 10000, dist = "poisson", data= data)
InterceptModel_ZIPESF <- update(base, . ~ 1) 
L_Int = logLik(base)
L_Ful = logLik(final_model3)
P_R2_MFad_ZIPESF = 1- L_Ful/L_Int
P_R2_MFad_ZIPESF

# table 3
obs = table(data$trademln)[1:10]
zip_esf = round(colSums(predict(final_model, type = "prob")[, 1:10]))
zip_esfc = round(colSums(predict(final_model2, type = "prob")[, 1:10]))
poisson_esf = round(colSums(predict(final_model3, type = "prob")[, 1:10]))

# table A1

# column (1): see column (1) in table 2

# column (2)

final_model4 = zeroinfl(trademln ~ lndistcap + comlang_off + contig + history + fta + logarea_i + logarea_e + lngdpcap_i + lngdpcap_e + lnpop_i + lnpop_e + island_i + island_e + landlocked_i + landlocked_e 
| lndistcap + comlang_off + contig + history + fta + logarea_i + logarea_e + lngdpcap_i + lngdpcap_e + lnpop_i + lnpop_e + island_i + island_e + landlocked_i + landlocked_e,
data = data, maxit = 10000, dist = "poisson")
#results
fit = coeftest(final_model4, vcov = sandwich1)
#akaike index criteria
AIC(final_model4)
# loglikelihood
logLik(final_model4)
# mcfadden R^2
base = zeroinfl(trademln ~ 1 |1 , maxit = 10000, dist = "poisson", data= data)
InterceptModel_ZIPESF <- update(base, . ~ 1) 
L_Int = logLik(base)
L_Ful = logLik(final_model4)
P_R2_MFad_ZIPESF = 1- L_Ful/L_Int
P_R2_MFad_ZIPESF

# column (3)

final_model5 = glm(trademln ~ lndistcap + comlang_off + contig + history + fta + logarea_i + logarea_e + lngdpcap_i + lngdpcap_e + lnpop_i + lnpop_e + island_i + island_e + landlocked_i + landlocked_e + 
factor(un_i) + factor(un_e), data = data, family = poisson(), maxit = 10000)
#results
fit = coeftest(final_model5, vcov = sandwich1)
#akaike index criteria
AIC(final_model5)
# loglikelihood
logLik(final_model5)
# mcfadden R^2
base = zeroinfl(trademln ~ 1 |1 , maxit = 10000, dist = "poisson", data= data)
InterceptModel_ZIPESF <- update(base, . ~ 1) 
L_Int = logLik(base)
L_Ful = logLik(final_model5)
P_R2_MFad_ZIPESF = 1- L_Ful/L_Int
P_R2_MFad_ZIPESF

## table A2

obs = table(data$trademln)[1:10]
zip_esf = round(colSums(predict(final_model, type = "prob")[, 1:10]))
zip = round(colSums(predict(final_model4, type = "prob")[, 1:10]))
poisson_fe = round(sapply(0:9, function(x) sum(dpois(x, fitted(final_model5)))))


